<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name></name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation>Il file non esiste</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation>il file %1 non è stato trovato. Si prega di verificare e riprovare nuovamente.</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <location filename="../src/dialogs.cpp" line="79"/>
        <source>Program Files</source>
        <translation type="obsolete">Programmi</translation>
    </message>
</context>
<context>
    <name>pageFinished</name>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC is now installed!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC è stato installato!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="71"/>
        <source>Save installation settings</source>
        <translation>Salva le impostazioni</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="61"/>
        <source>iTALC is now completely installed. If you installed the master application you can start it using the start-menu.</source>
        <translation>iTALC è stato installato. Se hai installato l&apos;applicazione Master, puoi avviarla utilizzando il Menu Start.</translation>
    </message>
</context>
<context>
    <name>pageInstallDir</name>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Choose installation directory&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Scegli la cartella di installazione&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="47"/>
        <source>Please choose the directory in which iTALC is going to be installed. It&apos;s recommended to leave the default-directory, but it&apos;s no problem to change it.</source>
        <translation>Scegliere la cartella in cui sarà installato  iTALC. E&apos; raccomandabile utilizzare la cartella predefinita, ma non è un problema utilizzarne un&apos;altra.</translation>
    </message>
</context>
<context>
    <name>pageKeyDirs</name>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Directories for keys&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Cartelle per le chiavi&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="47"/>
        <source>The newly created or imported key(s) need to be installed somewhere. It&apos;s recommended to leave the suggested directories.</source>
        <translation>Le chiavi di crittografia create o importate devono essere salvate. E&apos; raccomandabile utilizzare le cartelle predefinite.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="73"/>
        <source>Directory to store public key in</source>
        <translation>Cartella in cui salvare la chiave pubblica</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="147"/>
        <source>Directory to store private key in</source>
        <translation>Cartella in cui salvare la chiave privata</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="212"/>
        <source>You can choose a directory in which to export the public key, e.g. a USB-drive or a network share.</source>
        <translation>Puoi indicare una cartella in cui esportare la chiave pubblica, ad es. un drive-usb o una cartella di rete.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="258"/>
        <source>Export private key too</source>
        <translation>Esporta anche la chiave privata</translation>
    </message>
</context>
<context>
    <name>pageLicenseAgreement</name>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="40"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;License agreement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Licenza&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="50"/>
        <source>iTALC is published under the terms of the General Public License (GPL). Please read the following license terms and choose whether you agree or disagree the license.</source>
        <translation>iTALC è rilasciato sotto licenza General Public License (GPL). Leggere i termini della licenza qui sotto e scegliere se la si accetta o meno.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="81"/>
        <source>I agree</source>
        <translation>Accetto</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="88"/>
        <source>I disagree</source>
        <translation>Non accetto</translation>
    </message>
</context>
<context>
    <name>pageSecurityOptions</name>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="53"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Security options&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Opzioni di sicurezza&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="63"/>
        <source>iTALC has a sophisticated security-concept for preventing unauthorized access to computers having iTALC client software installed. Therefore you either have to create a new key-pair or import the public key created during iTALC installation on master computer.</source>
        <translation>iTALC è dotato di un sofisticato sistema di sicurezza (basato su chiavi crittografiche) per prevenire l&apos;accesso non autorizzato ai computer su cui è installato il software client di iTALC. 
Per questo, è necessario creare una nuova coppia di chiavi o importare la chiave pubblica creata durante l&apos;installazione dell&apos;applicazione master sul computer docente.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="73"/>
        <source>Create a new key-pair (only do that on master computer)</source>
        <translation>Crea una nuova coppia di chiavi (solo sul computer master)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="80"/>
        <source>Import public key of master computer</source>
        <translation>Importa la chiave pubblica del computer master</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="114"/>
        <source>Choose location of exported public key:</source>
        <translation>Scegli l&apos;ubicazione della chiave pubblica esportata:</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="152"/>
        <source>Keep all keys (only when updating existing installation!)</source>
        <translation>Mantieni tutte le chiavi (solo quando si aggiorna un&apos;installazione preesistente)</translation>
    </message>
</context>
<context>
    <name>pageSelectComponents</name>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Select components to install&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Seleziona i componenti da installare&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="55"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Now it&apos;s time to choose which components of iTALC you want to install on this computer. If this is a client-computer you should only install the client-software.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Please note, that the master application depends the client-software in order to function properly.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Ora è il momento di scegliere quali componenti di iTALC si vuole installare su questo computer. Se è un computer-client si deve installare solo il software client.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Si consideri che l&apos;applicazione&lt;b&gt;Master&lt;/b&gt;dipende dall&apos;applicazione&lt;b&gt;Client&lt;/b&gt; per funzionare correttamente.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="70"/>
        <source>Components</source>
        <translation>Componenti</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="93"/>
        <source>iTALC Client Appliction (ICA)</source>
        <translation>iTALC Applicazione Client  (ICA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="103"/>
        <source>iTALC Master Application (IMA)</source>
        <translation>iTALC Applicazione Master (IMA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="113"/>
        <source>Online-Update Service (LUPUS)</source>
        <translation>Servizio di aggiornamento online (LUPUS)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="123"/>
        <source>iTALC documentation</source>
        <translation>Documentazione di iTALC</translation>
    </message>
</context>
<context>
    <name>pageWelcome</name>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Welcome to installation of iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Benvenuto nell&apos;installazione di  iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="61"/>
        <source>This setup-wizard will guide you through the installation of iTALC on this computer. The installation includes the client-software as well as the optional master-application.

Furthermore you&apos;ll be able to setup security-settings.

Click &apos;Next&apos; to continue.</source>
        <translation>Questa installazione-guidata ti assisterà nell&apos;installazione di iTALC sul computer. L&apos;installazione prevede l&apos;applicazione client e opzionalmente anche l&apos;applicazione master.

Inoltre sarà possibile configurare l&apos;ambiente di sicurezza.

Clicca su &apos;Avanti&apos; per continuare.</translation>
    </message>
</context>
<context>
    <name>setupWizard</name>
    <message>
        <location filename="../src/dialogs.cpp" line="153"/>
        <source>Confirm overwrite</source>
        <translation>Conferma sovrascrittura</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="154"/>
        <source>Do you want to overwrite %1?</source>
        <translation>Vuoi sovrascrivere %1?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="211"/>
        <source>Installing iTALC</source>
        <translation>Installazione di iTALC</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="213"/>
        <source>Copying files...</source>
        <translation>Copia file in corso ...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="278"/>
        <source>Registering ICA as service...</source>
        <translation>Registrazione di ICA come servizio...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="321"/>
        <source>Creating/importing keys...</source>
        <translation>Creazione/importazione delle chiavi...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="353"/>
        <source>Creating shortcuts...</source>
        <translation>Creazione dei collegamenti...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="375"/>
        <source>Could not create directory</source>
        <translation>Non posso creare la cartella</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="379"/>
        <source>Could not create directory %1! Make sure you have the neccessary rights and try again!</source>
        <translation>Non è stato possibile creare la cartella %1! Accertati di avere i diritti necessari e riprova!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="392"/>
        <source>Cancel setup</source>
        <translation>Annulla installazione</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="394"/>
        <source>Are you sure want to quit setup? iTALC is not installed completely yet!</source>
        <translation>Sei sicuro di voler uscire dal programma di installazione? L&apos;installazione di iTALC non è ancora completa!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="414"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="473"/>
        <source>Finish</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="479"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>setupWizardPageInstallDir</name>
    <message>
        <location filename="../src/dialogs.cpp" line="568"/>
        <source>Directory does not exist</source>
        <translation>La cartella non esiste</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="570"/>
        <source>The specified directory does not exist. Do you want to create it?</source>
        <translation>La cartella indicata non esiste. Vuoi crearla?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="592"/>
        <source>Choose installation directory</source>
        <translation>Scegli la cartella di installazione</translation>
    </message>
</context>
<context>
    <name>setupWizardPageKeyDirs</name>
    <message>
        <location filename="../src/dialogs.cpp" line="826"/>
        <source>Choose public key directory</source>
        <translation>Scegli la cartella per la chiave pubblica</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="840"/>
        <source>Choose private key directory</source>
        <translation>Scegli la cartella per la chiave privata</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="854"/>
        <source>Choose public key export directory</source>
        <translation>Scegli la cartella in cui esportare le chiavi</translation>
    </message>
</context>
<context>
    <name>setupWizardPageSecurityOptions</name>
    <message>
        <location filename="../src/dialogs.cpp" line="728"/>
        <source>Choose directory for key-import</source>
        <translation>Scegli la cartella da cui importare le chiavi</translation>
    </message>
</context>
<context>
    <name>wizard</name>
    <message>
        <location filename="../dialogs/wizard.ui" line="21"/>
        <source>iTALC-Setup</source>
        <translation>Installazione di iTALC</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="67"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="77"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="87"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
</context>
</TS>
